Flask==0.11.1
Jinja2==2.8
MarkupSafe==0.23
Werkzeug==0.11.11
requests
numpy
clint
oauth2client
scipy
flask_restful
flask-jsonpify
pymongo
gspread
pandas
stringdist
sklearn
pythainlp
xlrd
gensim
pymongo
scikit-learn
uvicorn==0.11.5
sanic==20.3.0
gunicorn==19.9.0

